@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 
-__version__ = "2.1.1"
+__version__ = "2.2.1"
 
 import aie
 from .aie_env import AIEEnv
@@ -30,6 +30,12 @@ from aie.aie_object.terrain import Terrain
 
 from aie.aie_object.kernel import Kernel
 
+from aie.aie_object.classifier import Classifier
+
+from aie.aie_object.confusion_matrix import ConfusionMatrix
+
+from aie.aie_object.model import Model
+
 
 def Authenticate(token=None):
     aie.auth.Authenticate.auth(token)
