@@ -624,7 +624,9 @@ class FeatureCollection(aie.Collection):
         node = super(FeatureCollection, self).filter(filter)
         return FunctionHelper.cast(node, "aie.FeatureCollection")
 
-    def filterBounds(self, geometry: aie.Geometry) -> aie.FeatureCollection:
+    def filterBounds(
+        self, geometry: Union[aie.Geometry, aie.Feature, aie.FeatureCollection]
+    ) -> aie.FeatureCollection:
 
         node = super(FeatureCollection, self).filterBounds(geometry)
         return FunctionHelper.cast(node, "aie.FeatureCollection")
@@ -677,3 +679,92 @@ class FeatureCollection(aie.Collection):
             raise AIEError(AIEErrorCode.ARGS_ERROR, "参数count不能为空")
 
         return FunctionHelper.apply("FeatureCollection.toList", "object", invoke_args)
+
+    def sort(self, property: str, ascending: bool = True) -> aie.FeatureCollection:
+
+        if property is not None and not isinstance(property, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"property 只支持str类型参数, 传入类型为{type(property)}"
+            )
+
+        if ascending is not None and not isinstance(ascending, bool):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"ascending 只支持bool类型参数, 传入类型为{type(ascending)}",
+            )
+
+        invoke_args = {
+            "collection": self,
+            "property": property,
+            "ascending": ascending,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "property" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数property不能为空")
+
+        return FunctionHelper.apply(
+            "FeatureCollection.sort", "aie.FeatureCollection", invoke_args
+        )
+
+    def classify(
+        self, classifier: aie.Classifier, outputName: str = "classification"
+    ) -> aie.FeatureCollection:
+
+        if classifier is not None and not isinstance(classifier, aie.Classifier):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"classifier 只支持aie.Classifier类型参数, 传入类型为{type(classifier)}",
+            )
+
+        if outputName is not None and not isinstance(outputName, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"outputName 只支持str类型参数, 传入类型为{type(outputName)}",
+            )
+
+        invoke_args = {
+            "input": self,
+            "classifier": classifier,
+            "outputName": outputName,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "classifier" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数classifier不能为空")
+
+        return FunctionHelper.apply(
+            "FeatureCollection.classify", "aie.FeatureCollection", invoke_args
+        )
+
+    def errorMatrix(self, actual: str, predicted: str) -> aie.ConfusionMatrix:
+
+        if actual is not None and not isinstance(actual, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"actual 只支持str类型参数, 传入类型为{type(actual)}"
+            )
+
+        if predicted is not None and not isinstance(predicted, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"predicted 只支持str类型参数, 传入类型为{type(predicted)}"
+            )
+
+        invoke_args = {
+            "input": self,
+            "actual": actual,
+            "predicted": predicted,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "actual" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数actual不能为空")
+
+        if "predicted" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数predicted不能为空")
+
+        return FunctionHelper.apply(
+            "FeatureCollection.errorMatrix", "aie.ConfusionMatrix", invoke_args
+        )
