@@ -1290,12 +1290,14 @@ class Image(FunctionNode):
             "Image.reduceRegions", "aie.FeatureCollection", invoke_args
         )
 
-    def clip(self, geometry: aie.Geometry) -> aie.Image:
+    def clip(self, geometry: Union[aie.Geometry, aie.Feature]) -> aie.Image:
 
-        if geometry is not None and not isinstance(geometry, aie.Geometry):
+        if geometry is not None and not isinstance(
+            geometry, (aie.Geometry, aie.Feature)
+        ):
             raise AIEError(
                 AIEErrorCode.ARGS_ERROR,
-                f"geometry 只支持aie.Geometry类型参数, 传入类型为{type(geometry)}",
+                f"geometry 只支持(aie.Geometry,aie.Feature)类型参数, 传入类型为{type(geometry)}",
             )
 
         invoke_args = {
@@ -1450,6 +1452,26 @@ class Image(FunctionNode):
 
         return FunctionHelper.apply("Image.rgb", "aie.Image", invoke_args)
 
+    def rgbToHsv(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.rgbToHsv", "aie.Image", invoke_args)
+
+    def hsvToRgb(self) -> aie.Image:
+
+        invoke_args = {
+            "input": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.hsvToRgb", "aie.Image", invoke_args)
+
     def unitScale(self, low: [int, float], high: [int, float]) -> aie.Image:
 
         if low is not None and not isinstance(low, (int, float)):
@@ -1839,3 +1861,322 @@ class Image(FunctionNode):
             raise AIEError(AIEErrorCode.ARGS_ERROR, "参数kernel不能为空")
 
         return FunctionHelper.apply("Image.distance", "aie.Image", invoke_args)
+
+    def spectralDilation(
+        self, metric: str = "sam", kernel: aie.Kernel = None, useCentroid: bool = False
+    ) -> aie.Image:
+
+        if metric is not None and not isinstance(metric, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"metric 只支持str类型参数, 传入类型为{type(metric)}"
+            )
+
+        if kernel is not None and not isinstance(kernel, aie.Kernel):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"kernel 只支持aie.Kernel类型参数, 传入类型为{type(kernel)}",
+            )
+
+        if useCentroid is not None and not isinstance(useCentroid, bool):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"useCentroid 只支持bool类型参数, 传入类型为{type(useCentroid)}",
+            )
+
+        invoke_args = {
+            "image": self,
+            "metric": metric,
+            "kernel": kernel,
+            "useCentroid": useCentroid,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.spectralDilation", "aie.Image", invoke_args)
+
+    def spectralErosion(
+        self, metric: str = "sam", kernel: aie.Kernel = None, useCentroid: bool = False
+    ) -> aie.Image:
+
+        if metric is not None and not isinstance(metric, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"metric 只支持str类型参数, 传入类型为{type(metric)}"
+            )
+
+        if kernel is not None and not isinstance(kernel, aie.Kernel):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"kernel 只支持aie.Kernel类型参数, 传入类型为{type(kernel)}",
+            )
+
+        if useCentroid is not None and not isinstance(useCentroid, bool):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"useCentroid 只支持bool类型参数, 传入类型为{type(useCentroid)}",
+            )
+
+        invoke_args = {
+            "image": self,
+            "metric": metric,
+            "kernel": kernel,
+            "useCentroid": useCentroid,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.spectralErosion", "aie.Image", invoke_args)
+
+    def spectralGradient(
+        self, metric: str = "sam", kernel: aie.Kernel = None, useCentroid: bool = False
+    ) -> aie.Image:
+
+        if metric is not None and not isinstance(metric, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"metric 只支持str类型参数, 传入类型为{type(metric)}"
+            )
+
+        if kernel is not None and not isinstance(kernel, aie.Kernel):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"kernel 只支持aie.Kernel类型参数, 传入类型为{type(kernel)}",
+            )
+
+        if useCentroid is not None and not isinstance(useCentroid, bool):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"useCentroid 只支持bool类型参数, 传入类型为{type(useCentroid)}",
+            )
+
+        invoke_args = {
+            "image": self,
+            "metric": metric,
+            "kernel": kernel,
+            "useCentroid": useCentroid,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.spectralGradient", "aie.Image", invoke_args)
+
+    def spectralDistance(self, image2: aie.Image, metric: str = "sam") -> aie.Image:
+
+        if image2 is not None and not isinstance(image2, aie.Image):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"image2 只支持aie.Image类型参数, 传入类型为{type(image2)}"
+            )
+
+        if metric is not None and not isinstance(metric, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"metric 只支持str类型参数, 传入类型为{type(metric)}"
+            )
+
+        invoke_args = {
+            "image1": self,
+            "image2": image2,
+            "metric": metric,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "image2" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数image2不能为空")
+
+        return FunctionHelper.apply("Image.spectralDistance", "aie.Image", invoke_args)
+
+    def lanczos(self) -> aie.Image:
+
+        invoke_args = {
+            "value": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.lanczos", "aie.Image", invoke_args)
+
+    def pixelCoordinates(self, projection: str) -> aie.Image:
+
+        if projection is not None and not isinstance(projection, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"projection 只支持str类型参数, 传入类型为{type(projection)}",
+            )
+
+        invoke_args = {
+            "value": self,
+            "projection": projection,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "projection" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数projection不能为空")
+
+        return FunctionHelper.apply("Image.pixelCoordinates", "aie.Image", invoke_args)
+
+    def pixelLonLat(self) -> aie.Image:
+
+        invoke_args = {
+            "value": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.pixelLonLat", "aie.Image", invoke_args)
+
+    def unmix(self, endmembers: list) -> aie.Image:
+
+        if endmembers is not None and not isinstance(endmembers, list):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"endmembers 只支持list类型参数, 传入类型为{type(endmembers)}",
+            )
+
+        invoke_args = {
+            "image": self,
+            "endmembers": endmembers,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "endmembers" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数endmembers不能为空")
+
+        return FunctionHelper.apply("Image.unmix", "aie.Image", invoke_args)
+
+    def clipToCollection(self, collection: aie.FeatureCollection) -> aie.Image:
+
+        if collection is not None and not isinstance(collection, aie.FeatureCollection):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"collection 只支持aie.FeatureCollection类型参数, 传入类型为{type(collection)}",
+            )
+
+        invoke_args = {
+            "input": self,
+            "collection": collection,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "collection" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数collection不能为空")
+
+        return FunctionHelper.apply("Image.clipToCollection", "aie.Image", invoke_args)
+
+    def propertyNames(self) -> object:
+
+        invoke_args = {
+            "element": self,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        return FunctionHelper.apply("Image.propertyNames", "object", invoke_args)
+
+    def copyProperties(self, image2: aie.Image) -> aie.Image:
+
+        if image2 is not None and not isinstance(image2, aie.Image):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"image2 只支持aie.Image类型参数, 传入类型为{type(image2)}"
+            )
+
+        invoke_args = {
+            "image1": self,
+            "image2": image2,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "image2" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数image2不能为空")
+
+        return FunctionHelper.apply("Image.copyProperties", "aie.Image", invoke_args)
+
+    def classify(
+        self, classifier: aie.Classifier, outputName: str = "classification"
+    ) -> aie.Image:
+
+        if classifier is not None and not isinstance(classifier, aie.Classifier):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"classifier 只支持aie.Classifier类型参数, 传入类型为{type(classifier)}",
+            )
+
+        if outputName is not None and not isinstance(outputName, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"outputName 只支持str类型参数, 传入类型为{type(outputName)}",
+            )
+
+        invoke_args = {
+            "input": self,
+            "classifier": classifier,
+            "outputName": outputName,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "classifier" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数classifier不能为空")
+
+        return FunctionHelper.apply("Image.classify", "aie.Image", invoke_args)
+
+    def sample(
+        self,
+        region: aie.Geometry,
+        scale: [int, float],
+        numPixels: int,
+        seed: int = 0,
+        geometries: bool = False,
+    ) -> aie.FeatureCollection:
+
+        if region is not None and not isinstance(region, aie.Geometry):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"region 只支持aie.Geometry类型参数, 传入类型为{type(region)}",
+            )
+
+        if scale is not None and not isinstance(scale, (int, float)):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"scale 只支持(int,float)类型参数, 传入类型为{type(scale)}"
+            )
+
+        if numPixels is not None and not isinstance(numPixels, int):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"numPixels 只支持int类型参数, 传入类型为{type(numPixels)}"
+            )
+
+        if seed is not None and not isinstance(seed, int):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"seed 只支持int类型参数, 传入类型为{type(seed)}"
+            )
+
+        if geometries is not None and not isinstance(geometries, bool):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR,
+                f"geometries 只支持bool类型参数, 传入类型为{type(geometries)}",
+            )
+
+        invoke_args = {
+            "input": self,
+            "region": region,
+            "scale": scale,
+            "numPixels": numPixels,
+            "seed": seed,
+            "geometries": geometries,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "region" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数region不能为空")
+
+        if "scale" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数scale不能为空")
+
+        if "numPixels" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数numPixels不能为空")
+
+        return FunctionHelper.apply(
+            "Image.sample", "aie.FeatureCollection", invoke_args
+        )
