@@ -18,7 +18,10 @@ from aie.error.aie_error import AIEError, AIEErrorCode
 class Kernel(FunctionNode):
     @staticmethod
     def chebyshev(
-        radius: [int, float], normalize: bool = False, magnitude: [int, float] = 1.0
+        radius: [int, float],
+        units: str = "pixels",
+        normalize: bool = False,
+        magnitude: [int, float] = 1.0,
     ) -> aie.Kernel:
 
         if radius is not None and not isinstance(radius, (int, float)):
@@ -27,6 +30,11 @@ class Kernel(FunctionNode):
                 f"radius 只支持(int,float)类型参数, 传入类型为{type(radius)}",
             )
 
+        if units is not None and not isinstance(units, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"units 只支持str类型参数, 传入类型为{type(units)}"
+            )
+
         if normalize is not None and not isinstance(normalize, bool):
             raise AIEError(
                 AIEErrorCode.ARGS_ERROR,
@@ -41,6 +49,7 @@ class Kernel(FunctionNode):
 
         invoke_args = {
             "radius": radius,
+            "units": units,
             "normalize": normalize,
             "magnitude": magnitude,
         }
@@ -54,7 +63,10 @@ class Kernel(FunctionNode):
 
     @staticmethod
     def circle(
-        radius: [int, float], normalize: bool = False, magnitude: [int, float] = 1.0
+        radius: [int, float],
+        units: str = "pixels",
+        normalize: bool = False,
+        magnitude: [int, float] = 1.0,
     ) -> aie.Kernel:
 
         if radius is not None and not isinstance(radius, (int, float)):
@@ -63,6 +75,11 @@ class Kernel(FunctionNode):
                 f"radius 只支持(int,float)类型参数, 传入类型为{type(radius)}",
             )
 
+        if units is not None and not isinstance(units, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"units 只支持str类型参数, 传入类型为{type(units)}"
+            )
+
         if normalize is not None and not isinstance(normalize, bool):
             raise AIEError(
                 AIEErrorCode.ARGS_ERROR,
@@ -77,6 +94,7 @@ class Kernel(FunctionNode):
 
         invoke_args = {
             "radius": radius,
+            "units": units,
             "normalize": normalize,
             "magnitude": magnitude,
         }
@@ -114,7 +132,10 @@ class Kernel(FunctionNode):
 
     @staticmethod
     def cross(
-        radius: [int, float], normalize: bool = False, magnitude: [int, float] = 1.0
+        radius: [int, float],
+        units: str = "pixels",
+        normalize: bool = False,
+        magnitude: [int, float] = 1.0,
     ) -> aie.Kernel:
 
         if radius is not None and not isinstance(radius, (int, float)):
@@ -123,6 +144,11 @@ class Kernel(FunctionNode):
                 f"radius 只支持(int,float)类型参数, 传入类型为{type(radius)}",
             )
 
+        if units is not None and not isinstance(units, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"units 只支持str类型参数, 传入类型为{type(units)}"
+            )
+
         if normalize is not None and not isinstance(normalize, bool):
             raise AIEError(
                 AIEErrorCode.ARGS_ERROR,
@@ -137,6 +163,7 @@ class Kernel(FunctionNode):
 
         invoke_args = {
             "radius": radius,
+            "units": units,
             "normalize": normalize,
             "magnitude": magnitude,
         }
@@ -150,7 +177,10 @@ class Kernel(FunctionNode):
 
     @staticmethod
     def diamond(
-        radius: [int, float], normalize: bool = False, magnitude: [int, float] = 1.0
+        radius: [int, float],
+        units: str = "pixels",
+        normalize: bool = False,
+        magnitude: [int, float] = 1.0,
     ) -> aie.Kernel:
 
         if radius is not None and not isinstance(radius, (int, float)):
@@ -159,6 +189,11 @@ class Kernel(FunctionNode):
                 f"radius 只支持(int,float)类型参数, 传入类型为{type(radius)}",
             )
 
+        if units is not None and not isinstance(units, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"units 只支持str类型参数, 传入类型为{type(units)}"
+            )
+
         if normalize is not None and not isinstance(normalize, bool):
             raise AIEError(
                 AIEErrorCode.ARGS_ERROR,
@@ -173,6 +208,7 @@ class Kernel(FunctionNode):
 
         invoke_args = {
             "radius": radius,
+            "units": units,
             "normalize": normalize,
             "magnitude": magnitude,
         }
@@ -186,7 +222,10 @@ class Kernel(FunctionNode):
 
     @staticmethod
     def euclidean(
-        radius: [int, float], normalize: bool = False, magnitude: [int, float] = 1.0
+        radius: [int, float],
+        units: str = "pixels",
+        normalize: bool = False,
+        magnitude: [int, float] = 1.0,
     ) -> aie.Kernel:
 
         if radius is not None and not isinstance(radius, (int, float)):
@@ -195,6 +234,11 @@ class Kernel(FunctionNode):
                 f"radius 只支持(int,float)类型参数, 传入类型为{type(radius)}",
             )
 
+        if units is not None and not isinstance(units, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"units 只支持str类型参数, 传入类型为{type(units)}"
+            )
+
         if normalize is not None and not isinstance(normalize, bool):
             raise AIEError(
                 AIEErrorCode.ARGS_ERROR,
@@ -209,6 +253,7 @@ class Kernel(FunctionNode):
 
         invoke_args = {
             "radius": radius,
+            "units": units,
             "normalize": normalize,
             "magnitude": magnitude,
         }
@@ -250,6 +295,7 @@ class Kernel(FunctionNode):
     def gaussian(
         radius: [int, float],
         sigma: [int, float] = 1.0,
+        units: str = "pixels",
         normalize: bool = False,
         magnitude: [int, float] = 1.0,
     ) -> aie.Kernel:
@@ -265,6 +311,11 @@ class Kernel(FunctionNode):
                 AIEErrorCode.ARGS_ERROR, f"sigma 只支持(int,float)类型参数, 传入类型为{type(sigma)}"
             )
 
+        if units is not None and not isinstance(units, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"units 只支持str类型参数, 传入类型为{type(units)}"
+            )
+
         if normalize is not None and not isinstance(normalize, bool):
             raise AIEError(
                 AIEErrorCode.ARGS_ERROR,
@@ -280,6 +331,7 @@ class Kernel(FunctionNode):
         invoke_args = {
             "radius": radius,
             "sigma": sigma,
+            "units": units,
             "normalize": normalize,
             "magnitude": magnitude,
         }
@@ -369,7 +421,10 @@ class Kernel(FunctionNode):
 
     @staticmethod
     def manhattan(
-        radius: [int, float], normalize: bool = False, magnitude: [int, float] = 1.0
+        radius: [int, float],
+        units: str = "pixels",
+        normalize: bool = False,
+        magnitude: [int, float] = 1.0,
     ) -> aie.Kernel:
 
         if radius is not None and not isinstance(radius, (int, float)):
@@ -378,6 +433,11 @@ class Kernel(FunctionNode):
                 f"radius 只支持(int,float)类型参数, 传入类型为{type(radius)}",
             )
 
+        if units is not None and not isinstance(units, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"units 只支持str类型参数, 传入类型为{type(units)}"
+            )
+
         if normalize is not None and not isinstance(normalize, bool):
             raise AIEError(
                 AIEErrorCode.ARGS_ERROR,
@@ -392,6 +452,7 @@ class Kernel(FunctionNode):
 
         invoke_args = {
             "radius": radius,
+            "units": units,
             "normalize": normalize,
             "magnitude": magnitude,
         }
@@ -405,7 +466,10 @@ class Kernel(FunctionNode):
 
     @staticmethod
     def plus(
-        radius: [int, float], normalize: bool = False, magnitude: [int, float] = 1.0
+        radius: [int, float],
+        units: str = "pixels",
+        normalize: bool = False,
+        magnitude: [int, float] = 1.0,
     ) -> aie.Kernel:
 
         if radius is not None and not isinstance(radius, (int, float)):
@@ -414,6 +478,11 @@ class Kernel(FunctionNode):
                 f"radius 只支持(int,float)类型参数, 传入类型为{type(radius)}",
             )
 
+        if units is not None and not isinstance(units, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"units 只支持str类型参数, 传入类型为{type(units)}"
+            )
+
         if normalize is not None and not isinstance(normalize, bool):
             raise AIEError(
                 AIEErrorCode.ARGS_ERROR,
@@ -428,6 +497,7 @@ class Kernel(FunctionNode):
 
         invoke_args = {
             "radius": radius,
+            "units": units,
             "normalize": normalize,
             "magnitude": magnitude,
         }
@@ -467,6 +537,7 @@ class Kernel(FunctionNode):
     def rectangle(
         xRadius: [int, float],
         yRadius: [int, float],
+        units: str = "pixels",
         normalize: bool = False,
         magnitude: [int, float] = 1.0,
     ) -> aie.Kernel:
@@ -483,6 +554,11 @@ class Kernel(FunctionNode):
                 f"yRadius 只支持(int,float)类型参数, 传入类型为{type(yRadius)}",
             )
 
+        if units is not None and not isinstance(units, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"units 只支持str类型参数, 传入类型为{type(units)}"
+            )
+
         if normalize is not None and not isinstance(normalize, bool):
             raise AIEError(
                 AIEErrorCode.ARGS_ERROR,
@@ -498,6 +574,7 @@ class Kernel(FunctionNode):
         invoke_args = {
             "xRadius": xRadius,
             "yRadius": yRadius,
+            "units": units,
             "normalize": normalize,
             "magnitude": magnitude,
         }
@@ -562,7 +639,10 @@ class Kernel(FunctionNode):
 
     @staticmethod
     def square(
-        radius: [int, float], normalize: bool = False, magnitude: [int, float] = 1.0
+        radius: [int, float],
+        units: str = "pixels",
+        normalize: bool = False,
+        magnitude: [int, float] = 1.0,
     ) -> aie.Kernel:
 
         if radius is not None and not isinstance(radius, (int, float)):
@@ -571,6 +651,11 @@ class Kernel(FunctionNode):
                 f"radius 只支持(int,float)类型参数, 传入类型为{type(radius)}",
             )
 
+        if units is not None and not isinstance(units, str):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"units 只支持str类型参数, 传入类型为{type(units)}"
+            )
+
         if normalize is not None and not isinstance(normalize, bool):
             raise AIEError(
                 AIEErrorCode.ARGS_ERROR,
@@ -585,6 +670,7 @@ class Kernel(FunctionNode):
 
         invoke_args = {
             "radius": radius,
+            "units": units,
             "normalize": normalize,
             "magnitude": magnitude,
         }
