@@ -298,3 +298,63 @@ class Reducer(FunctionNode):
         return FunctionHelper.apply(
             "Reducer.sampleVariance", "aie.Reducer", invoke_args
         )
+
+    @staticmethod
+    def histogram(buckets: int) -> aie.Reducer:
+
+        if buckets is not None and not isinstance(buckets, int):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"buckets 只支持int类型参数, 传入类型为{type(buckets)}"
+            )
+
+        invoke_args = {
+            "buckets": buckets,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "buckets" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数buckets不能为空")
+
+        return FunctionHelper.apply("Reducer.histogram", "aie.Reducer", invoke_args)
+
+    @staticmethod
+    def fixedHistogram(
+        min: [int, float], max: [int, float], buckets: int
+    ) -> aie.Reducer:
+
+        if min is not None and not isinstance(min, (int, float)):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"min 只支持(int,float)类型参数, 传入类型为{type(min)}"
+            )
+
+        if max is not None and not isinstance(max, (int, float)):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"max 只支持(int,float)类型参数, 传入类型为{type(max)}"
+            )
+
+        if buckets is not None and not isinstance(buckets, int):
+            raise AIEError(
+                AIEErrorCode.ARGS_ERROR, f"buckets 只支持int类型参数, 传入类型为{type(buckets)}"
+            )
+
+        invoke_args = {
+            "min": min,
+            "max": max,
+            "buckets": buckets,
+        }
+
+        invoke_args = {k: v for k, v in invoke_args.items() if v is not None}
+
+        if "min" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数min不能为空")
+
+        if "max" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数max不能为空")
+
+        if "buckets" not in invoke_args:
+            raise AIEError(AIEErrorCode.ARGS_ERROR, "参数buckets不能为空")
+
+        return FunctionHelper.apply(
+            "Reducer.fixedHistogram", "aie.Reducer", invoke_args
+        )
