@@ -173,3 +173,30 @@ class InteractiveSession():
             raise AIEError(payload["output"]["error_code"],
                            payload["output"]["error_message"], json.dumps(extrainfo))
         return payload["output"]["data"]["application/json"]
+
+    @staticmethod
+    def classifierTrain(obj):
+        expr = aie.serialize.serializer.encode(obj)
+        options = {
+            "taskType": "getResult"
+        }
+        task_id = newUUID()
+        data = {
+            "taskId": task_id,
+            "sessionId": InteractiveSession.getCurrentSessionId(),
+            "script": "{\"expression\":" + expr + "}",
+            "options": json.dumps(options)
+        }
+
+        url = Endpoints.INTERACTIVE_SESSION + InteractiveSessionResource.EXEC
+        payload = InteractiveSessionClient.post(url, data)
+        if payload["state"] == "cancelled":
+            raise AIEError(AIEErrorCode.JOB_CANCELLED, "该任务已取消")
+
+        if payload["state"] != "success":
+            extrainfo = {}
+            if "taskId" in data:
+                extrainfo["taskId"] = data["taskId"]
+            raise AIEError(payload["output"]["error_code"],
+                           payload["output"]["error_message"], json.dumps(extrainfo))
+        return payload["output"]["data"]["application/json"]
