@@ -21,4 +21,4 @@ class Serializer(object):
         # value = visitor.visit(obj)
         # result = {"result": 0, "values": {"0": value}}
 
-        return json.dumps(result, ensure_ascii=False)
+        return json.dumps(result, ensure_ascii=False, allow_nan=False)
